@@ -77,6 +77,17 @@ struct Success
 void
 from_json(const nlohmann::json &obj, Success &response);
 
+//! Some endpoints return this to indicate availability in addition to the http code (i.e. a
+//! username).
+struct Available
+{
+    //! Required. A flag to indicate that the resource is available.
+    bool available;
+};
+
+void
+from_json(const nlohmann::json &obj, Available &response);
+
 //! Responses to the `/requestToken` endpoints
 struct RequestToken
 {
@@ -116,7 +127,7 @@ void
 log_error(std::exception &err, const nlohmann::json &event);
 
 void
-log_error(std::string err, const nlohmann::json &event);
+log_error(const std::string &err, const nlohmann::json &event);
 
 //! Parse multiple account_data events.
 void
@@ -145,5 +156,13 @@ parse_device_events(const nlohmann::json &events, DeviceEvents &container);
 void
 parse_ephemeral_events(const nlohmann::json &events, EphemeralEvents &container);
 }
+
+//! An array of state events
+struct StateEvents
+{
+    utils::StateEvents events;
+};
+void
+from_json(const nlohmann::json &arr, StateEvents &response);
 }
 }
