@@ -51,6 +51,7 @@ struct PushersData;
 struct SetPushers;
 }
 namespace responses {
+struct Available;
 struct AvatarUrl;
 struct ClaimKeys;
 struct ContentURI;
@@ -71,6 +72,7 @@ struct Notifications;
 struct Profile;
 struct PublicRoomVisibility;
 struct PublicRooms;
+struct HierarchyRooms;
 struct QueryDevices;
 struct QueryKeys;
 struct Register;
@@ -79,6 +81,7 @@ struct RequestToken;
 struct RoomId;
 struct Success;
 struct Sync;
+struct StateEvents;
 struct TurnServer;
 struct UploadKeys;
 struct Version;
@@ -210,6 +213,11 @@ public:
     void set_server(const std::string &server);
     //! Retrieve the homeserver domain name.
     std::string server() { return server_; };
+    //! Retrieve the full server url including protocol and ports
+    std::string server_url()
+    {
+        return protocol_ + "://" + server() + ":" + std::to_string(port());
+    };
     //! Set the homeserver port.
     void set_port(uint16_t port) { port_ = port; };
     //! Retrieve the homeserver port.
@@ -252,18 +260,26 @@ public:
 
     //! Get the supported login flows
     void get_login(Callback<mtx::responses::LoginFlows> cb);
-    //! Get url to navigate to for sso login flow
+    //! Get url to navigate to for sso login flow, optionally preselecting an identity provider
     //! Open this in a browser
-    std::string login_sso_redirect(std::string redirectUrl);
+    std::string login_sso_redirect(std::string redirectUrl, const std::string &idp = "");
     //! Lookup real server to connect to.
     //! Call set_server with the returned homeserver url after this
     void well_known(Callback<mtx::responses::WellKnown> cb);
 
+    //! Check for username availability
+    void register_username_available(const std::string &username,
+                                     Callback<mtx::responses::Available> cb);
+
     //! Register with an UIA handler so you don't need to repeat the request manually.
     void registration(const std::string &user,
                       const std::string &pass,
                       UIAHandler uia_handler,
-                      Callback<mtx::responses::Register> cb);
+                      Callback<mtx::responses::Register> cb,
+                      const std::string &initial_device_display_name = "");
+
+    //! Send a dummy registration request to query the auth flows
+    void registration(Callback<mtx::responses::Register> cb);
 
     //! Check the validity of a registration token
     void registration_token_validity(const std::string token,
@@ -424,12 +440,16 @@ public:
     void versions(Callback<mtx::responses::Versions> cb);
 
     //! Mark an event as read.
-    void read_event(const std::string &room_id, const std::string &event_id, ErrCallback cb);
+    void read_event(const std::string &room_id,
+                    const std::string &event_id,
+                    ErrCallback cb,
+                    bool hidden = false);
 
     //! Redact an event from a room.
     void redact_event(const std::string &room_id,
                       const std::string &event_id,
-                      Callback<mtx::responses::EventId> cb);
+                      Callback<mtx::responses::EventId> cb,
+                      const std::string &reason = "");
 
     //! Upload a filter
     void upload_filter(const nlohmann::json &j, Callback<mtx::responses::FilterId> cb);
@@ -451,6 +471,7 @@ public:
                                      const std::string &content_type,
                                      const std::string &original_filename,
                                      RequestErr err)> cb);
+    std::string mxc_to_download_url(const std::string &mxc_url);
 
     //! Retrieve a thumbnail from the given mxc url.
     //! If the thumbnail isn't found and `try_download` is `true` it will try
@@ -474,6 +495,9 @@ public:
                    const std::string &event_id,
                    Callback<mtx::events::collections::TimelineEvents> cb);
 
+    //! Retrieve the whole state of a room
+    void get_state(const std::string &room_id, Callback<mtx::responses::StateEvents> payload);
+
     //! Retrieve a single state event.
     template<class Payload>
     void get_state_event(const std::string &room_id,
@@ -586,6 +610,15 @@ public:
                            Callback<mtx::responses::PublicRooms> cb,
                            const std::string &server = "");
 
+    //! Paginates over the space tree in a depth-first manner to locate child rooms of a given
+    //! space.
+    void get_hierarchy(const std::string &room_id,
+                       Callback<mtx::responses::HierarchyRooms> cb,
+                       const std::string &from = "",
+                       size_t limit            = 0,
+                       size_t max_depth        = 0,
+                       bool suggested_only     = false);
+
     //
     // Group related endpoints.
     //
@@ -637,7 +670,7 @@ public:
                                 Callback<mtx::responses::KeySignaturesUpload> cb);
 
     //! Upload cross signing keys
-    void device_signing_upload(const mtx::requests::DeviceSigningUpload,
+    void device_signing_upload(const mtx::requests::DeviceSigningUpload &,
                                UIAHandler uia_handler,
                                ErrCallback cb);
 
@@ -818,6 +851,7 @@ MTXCLIENT_SEND_STATE_EVENT_FWD(state::PinnedEvents)
 MTXCLIENT_SEND_STATE_EVENT_FWD(state::PowerLevels)
 MTXCLIENT_SEND_STATE_EVENT_FWD(state::Tombstone)
 MTXCLIENT_SEND_STATE_EVENT_FWD(state::Topic)
+MTXCLIENT_SEND_STATE_EVENT_FWD(state::Widget)
 MTXCLIENT_SEND_STATE_EVENT_FWD(state::space::Child)
 MTXCLIENT_SEND_STATE_EVENT_FWD(state::space::Parent)
 MTXCLIENT_SEND_STATE_EVENT_FWD(msc2545::ImagePack)
