@@ -103,8 +103,8 @@ from_json(const nlohmann::json &obj, PushRule &rule)
     rule.enabled  = obj.value("enabled", true);
 
     if (obj.contains("actions"))
-        for (auto action : obj["actions"])
-            rule.actions.push_back(action);
+        for (const auto &action : obj["actions"])
+            rule.actions.push_back(action.get<actions::Action>());
 
     rule.pattern = obj.value("pattern", "");
 
