@@ -65,6 +65,12 @@ from_json(const nlohmann::json &obj, Success &success)
     success.success = obj.at("success");
 }
 
+void
+from_json(const nlohmann::json &obj, Available &response)
+{
+    response.available = obj.at("available");
+}
+
 void
 from_json(const nlohmann::json &obj, RequestToken &r)
 {
@@ -84,7 +90,7 @@ log_error(std::exception &err, const json &event)
 }
 
 void
-log_error(std::string err, const json &event)
+log_error(const std::string &err, const json &event)
 {
     std::cout << err << std::endl;
     std::cout << event.dump(2) << std::endl;
@@ -207,6 +213,8 @@ parse_room_account_data_events(
         case events::EventType::RoomRedaction:
         case events::EventType::RoomTombstone:
         case events::EventType::RoomTopic:
+        case events::EventType::Widget:
+        case events::EventType::VectorWidget:
         case events::EventType::SpaceChild:
         case events::EventType::SpaceParent:
         case events::EventType::Sticker:
@@ -396,6 +404,24 @@ parse_timeline_events(const json &events,
 
                 break;
             }
+            case events::EventType::Widget: {
+                try {
+                    container.emplace_back(events::StateEvent<Widget>(e));
+                } catch (json::exception &err) {
+                    log_error(err, e);
+                }
+
+                break;
+            }
+            case events::EventType::VectorWidget: {
+                try {
+                    container.emplace_back(events::StateEvent<Widget>(e));
+                } catch (json::exception &err) {
+                    log_error(err, e);
+                }
+
+                break;
+            }
             case events::EventType::SpaceChild: {
                 try {
                     container.emplace_back(events::StateEvent<space::Child>(e));
@@ -982,6 +1008,24 @@ parse_state_events(const json &events,
 
                 break;
             }
+            case events::EventType::Widget: {
+                try {
+                    container.emplace_back(events::StateEvent<Widget>(e));
+                } catch (json::exception &err) {
+                    log_error(err, e);
+                }
+
+                break;
+            }
+            case events::EventType::VectorWidget: {
+                try {
+                    container.emplace_back(events::StateEvent<Widget>(e));
+                } catch (json::exception &err) {
+                    log_error(err, e);
+                }
+
+                break;
+            }
             case events::EventType::SpaceChild: {
                 try {
                     container.emplace_back(events::StateEvent<space::Child>(e));
@@ -1193,6 +1237,24 @@ parse_stripped_events(const json &events,
 
                 break;
             }
+            case events::EventType::Widget: {
+                try {
+                    container.emplace_back(events::StrippedEvent<Widget>(e));
+                } catch (json::exception &err) {
+                    log_error(err, e);
+                }
+
+                break;
+            }
+            case events::EventType::VectorWidget: {
+                try {
+                    container.emplace_back(events::StrippedEvent<Widget>(e));
+                } catch (json::exception &err) {
+                    log_error(err, e);
+                }
+
+                break;
+            }
             case events::EventType::SpaceChild: {
                 try {
                     container.emplace_back(events::StrippedEvent<space::Child>(e));
@@ -1313,5 +1375,10 @@ parse_ephemeral_events(const json &events,
     }
 }
 }
+void
+from_json(const nlohmann::json &arr, StateEvents &response)
+{
+    utils::parse_state_events(arr, response.events);
+}
 }
 }
