@@ -35,6 +35,12 @@ TEST(ClientAPI, Register)
                                      "M_USER_IN_USE");
                        });
 
+    user->register_username_available(
+      "alice", [](const mtx::responses::Available &, RequestErr err) {
+          ASSERT_TRUE(err);
+          EXPECT_EQ(err->matrix_error.errcode, mtx::errors::ErrorCode::M_USER_IN_USE);
+      });
+
     auto username = utils::random_token(10, false);
 
     // Synapse converts the username to lowercase.
@@ -42,6 +48,12 @@ TEST(ClientAPI, Register)
         c = (char)std::tolower(c);
     }
 
+    user->register_username_available(
+      username + "a", [](const mtx::responses::Available &available, RequestErr err) {
+          check_error(err);
+          EXPECT_TRUE(available.available);
+      });
+
     user->registration(
       username,
       "secret",
@@ -69,6 +81,12 @@ TEST(ClientAPI, Register)
           EXPECT_EQ(user->device_id(), res.device_id);
       });
 
+    user->registration([](const mtx::responses::Register &, RequestErr err) {
+        ASSERT_TRUE(err);
+        EXPECT_EQ(err->status_code, 401);
+        EXPECT_FALSE(err->matrix_error.unauthorized.flows.empty());
+    });
+
     user->close();
 }
 
@@ -374,7 +392,9 @@ TEST(ClientAPI, RoomAccountData)
           check_error(err);
 
           mtx::events::account_data::nheko_extensions::HiddenEvents hiddenEv;
-          hiddenEv.hidden_event_types.push_back(mtx::events::EventType::RoomMember);
+          hiddenEv.hidden_event_types = std::vector{
+            mtx::events::EventType::RoomMember,
+          };
 
           mtx_client->put_room_account_data(
             room_id.to_string(), hiddenEv, [mtx_client, room_id](RequestErr err) {
@@ -387,8 +407,8 @@ TEST(ClientAPI, RoomAccountData)
                      RequestErr err) {
                       check_error(err);
 
-                      ASSERT_EQ(hiddenEv.hidden_event_types.size(), 1);
-                      EXPECT_EQ(hiddenEv.hidden_event_types.at(0),
+                      ASSERT_EQ(hiddenEv.hidden_event_types->size(), 1);
+                      EXPECT_EQ(hiddenEv.hidden_event_types->at(0),
                                 mtx::events::EventType::RoomMember);
                   });
             });
@@ -410,7 +430,9 @@ TEST(ClientAPI, AccountData)
         sleep();
 
     mtx::events::account_data::nheko_extensions::HiddenEvents hiddenEv;
-    hiddenEv.hidden_event_types.push_back(mtx::events::EventType::RoomMember);
+    hiddenEv.hidden_event_types = std::vector{
+      mtx::events::EventType::RoomMember,
+    };
 
     mtx_client->put_account_data(hiddenEv, [mtx_client](RequestErr err) {
         check_error(err);
@@ -420,8 +442,8 @@ TEST(ClientAPI, AccountData)
                        RequestErr err) {
               check_error(err);
 
-              ASSERT_EQ(hiddenEv.hidden_event_types.size(), 1);
-              EXPECT_EQ(hiddenEv.hidden_event_types.at(0), mtx::events::EventType::RoomMember);
+              ASSERT_EQ(hiddenEv.hidden_event_types->size(), 1);
+              EXPECT_EQ(hiddenEv.hidden_event_types->at(0), mtx::events::EventType::RoomMember);
           });
     });
 
@@ -850,6 +872,42 @@ TEST(ClientAPI, Sync)
     mtx_client->close();
 }
 
+TEST(ClientAPI, State)
+{
+    std::shared_ptr<Client> mtx_client = make_test_client();
+
+    mtx_client->login(
+      "alice", "secret", [mtx_client](const mtx::responses::Login &, RequestErr err) {
+          check_error(err);
+      });
+
+    while (mtx_client->access_token().empty())
+        sleep();
+
+    mtx::requests::CreateRoom req;
+    req.name  = "Name";
+    req.topic = "Topic";
+    mtx_client->create_room(req, [mtx_client](const mtx::responses::CreateRoom &r, RequestErr err) {
+        check_error(err);
+
+        mtx_client->get_state(
+          r.room_id.to_string(), [](const mtx::responses::StateEvents &res, RequestErr err) {
+              check_error(err);
+              ASSERT_TRUE(res.events.size() > 0);
+              bool found_name_event = false;
+
+              for (const auto &e : res.events) {
+                  auto ev = std::get_if<mtx::events::StateEvent<mtx::events::state::Name>>(&e);
+                  if (ev && ev->content.name == "Name")
+                      found_name_event = true;
+              }
+              EXPECT_TRUE(found_name_event);
+          });
+    });
+
+    mtx_client->close();
+}
+
 TEST(ClientAPI, Versions)
 {
     std::shared_ptr<Client> mtx_client = make_test_client();
@@ -987,6 +1045,7 @@ TEST(ClientAPI, PresenceOverSync)
       req, [alice, bob, &can_exit](const mtx::responses::CreateRoom &res, RequestErr err) {
           check_error(err);
           auto room_id = res.room_id.to_string();
+          ASSERT_FALSE(room_id.empty());
 
           bob->join_room(
             room_id,
